from typing import Optional


class TestResult:
    def __init__(self, success:Optional[bool]=True, message:Optional[str]=None):
        self.__success = success
        self.__message = message

    def __str__(self):
        return '测试成功' if self.__success else f'测试失败：{self.__message}'

    @classmethod
    def fail(cls, message:str):
        return TestResult(success=False, message=message)


from enum import Enum
from typing import Optional, Union


class BaseEnum(Enum):
    def __init__(self, code: Optional[Union[str or int]] = None, desc: Optional[str] = None):
        self.code = code
        self.desc = desc

    @classmethod
    def get_by_code(cls, code: Optional[Union[str or int]]):
        """
        根据代码获取枚举
        :param code: 代码
        :return: 枚举
        """
        for _enum in cls:
            if _enum.code == code:
                return _enum
        return None

    @classmethod
    def get_by_desc(cls, desc: str):
        for _enum in cls:
            if _enum.desc == desc:
                return _enum
        return None



from mag_tools.model.base_enum import BaseEnum


class DimensionType(BaseEnum):
    DX = ('dx', 'Dimension X')  # 维度X
    DY = ('dy', 'Dimension Y')  # 维度Y
    DZ = ('dz', 'Dimension Z')  # 维度Z


if __name__ == '__main__':
    # 示例用法
    print(DimensionType.DX.code)  # 输出: dx
    print(DimensionType.DY.desc)  # 输出: Dimension Y
    print(DimensionType.get_by_code('dx').desc)  # 输出: Dimension X



from typing import Optional
import allure

from mag_tools.bean.common.test_result import TestResult
from mag_tools.utils.common.string_utils import StringUtils

from mag_tools.model.common.log_type import LogType

from mag_tools.log.logger import Logger
from mag_tools.model.test.test_component_type import TestComponentType


class BaseTest:
    def __init__(self, name:str, index:Optional[int]=None, test_component_type:Optional[TestComponentType] = None, description:Optional[str]=None):
        self._name = name
        self._index = index
        self._test_component_type = test_component_type
        self._description = description
        self._test_result = TestResult()

    def _report(self):
        Logger.info(LogType.FRAME, f"执行{self._test_component_type.desc}({self._name})完毕")

        if self._test_component_type == TestComponentType.MODULE:
            index_ch = StringUtils.to_chinese_number(self._index) + "、" if self._index else ""
            allure.dynamic.feature(f"{index_ch}{self._name}")  # 所属功能模块
        elif self._test_component_type == TestComponentType.CASE:
            allure.dynamic.title(self._name)  # 测试用例名（标题）
            if self._description:
                allure.dynamic.story(self._description)  # 测试用例描述
        elif self._test_component_type == TestComponentType.FUNCTION:
            title = self._description if self._description else (self._name if self._name else '')
            allure.step(f"{self._index} {title}  {self._test_result}")  # 描述测试功能
        elif self._test_component_type == TestComponentType.STEP:
            title = self._description if self._description else (self._name if self._name else '')
            allure.step(f"  {self._index} {title}  {self._test_result}")  # 描述测试步骤

    def start(self, driver):
        raise NotImplementedError("This method should be overridden in subclasses")